#
# spec file for package eyeD3
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           eyeD3
Version:        0.9.7
Release:        2.4
Summary:        Audio files and ID3 Manipulation Tool
License:        GPL-2.0-or-later AND GPL-3.0-only
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://eyed3.readthedocs.io/en/latest/
Source:         https://files.pythonhosted.org/packages/source/e/eyeD3/eyeD3-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildArch:      noarch
# %%primary_python not available in Leap yet
Requires:       %(echo %{python_module eyed3} | perl -pe 's{.* }{}g')
%define python_subpackage_only 1
%python_subpackages

%description
eyeD3 is a Python tool for working with audio files, specifically MP3
files containing ID3 metadata (i.e. song info).

Features:
- Python package for writing application and/or plugins.
- Command-line tool driver script that supports plugins. viewer/editor
  interface.
- Easy editing/viewing of audio metadata from the command-line, using the
  ‘classic’ plugin.
- Support for ID3 versions 1.x, 2.2 (read-only), 2.3, and 2.4.
- Support for the MP3 audio format exposing details such as play time,
  bit rate, sampling frequency, etc.
- Abstract design allowing future support for different audio formats and
  metadata containers.

%package -n python-eyed3
Summary:        Component library of eyeD3, an ID3 tag manipulation tool
Group:          Development/Languages/Python
Requires:       python-chardet >= 4.0.0
Requires:       python-colorama >= 0.4.4
Requires:       python-deprecation >= 2.1.0
Requires:       python-filetype >= 1.0.7
Requires:       python-idna >= 2.10
Requires:       python-packaging >= 20.8
Requires:       python-pyparsing >= 2.4.7
Requires:       python-requests >= 2.25.1
Requires:       python-six >= 1.15.0
Requires:       python-toml >= 0.10.2
Requires:       python-urllib3 >= 1.26.2
Recommends:     python-grako
Recommends:     python-pillow
# for plugins
Recommends:     python-pylast
Recommends:     python-requests
Recommends:     python-ruamel.yaml

%description -n python-eyed3
eyeD3 is a Python tool for working with audio files, specifically MP3
files containing ID3 metadata (i.e. song info).

%prep
%autosetup -p1
# currently broken
rm eyed3/plugins/mimetype.py

%build
%python_build
#python3.11 setup.py build

%install
%python_install
#python3.11 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%license LICENSE
%doc AUTHORS.rst
%doc README.rst
%doc CONTRIBUTING.rst
%doc HISTORY.rst
#%doc docs
#%doc examples
%{_bindir}/eyeD3

%files %{python_files eyed3}
%{python_sitelib}/eyed3*

%changelog
* Fri Nov 10 2023 Jan Engelhardt <jengelh@inai.de>
- Implement multipython build
* Thu Nov  9 2023 marec@detebe.org
- explicitly use python 3.11
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.7:
  - [fixup-plugin] Added --no-dir-rename.
  - Add remove-all-unknown to classic plugin. <gobater@users.noreply.github.com>
  - Track/disc number support for JSON/YAML plugins (and tests)
  - CountAndTotalTuple named tuple for count/total values.
  - EyeD3 __all__ includes core.AudioFile.
  - AudioFile.__str__ returns path.
  - Strict render Frame flag to continue on render errors. Applied to RelVolAdjFrameV24, etc
  - Track unsupported frames and add `--remove-all-unknown` classic plugin
    option (#586) <gobater@users.noreply.github.com>
  - Removed display-plugin due to Grako EOL (#585)
  - [stats] Print bytes as text and filter private members.
  - Remove Python 3.6 support, EOL. (#560)
  - Doc grammar fixed (#537) <74979584+piatrashkakanstantinass@users.noreply.github.com>
  - Fix problem when frame file format invalid, and input.read() returns
    no more data at all - this had the potential to loop endlessly. (#539)
    <gerson.kurz@ng-branch-technology.com, gerson.kurz@gmail.com>
* Wed Aug 25 2021 Adrian Schröter <adrian@suse.de>
- update to 0.9.6
  * prepare for python 3.9
- dependency fixes
* Fri Jan 15 2021 Adrian Schröter <adrian@suse.de>
- add minimal runtime requires
- add some recommends needed for plugins
* Mon Jan 11 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- Add missing BuildRequires: python3-filetype python3-deprecation
  * Fix: pkg_resources.DistributionNotFound: filetype, deprecation distribution not found
* Fri Aug 21 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.9.5:
  - Dropped support for Python versions 2.7, 3.4, and 3.5.
  - File scanning is no longer recursive by default; use `-r / --recursive`.
  - Default log-level changed from WARNING to ERROR.
  - Mime-type detection uses filetype.py (libmagic no longer required)
  - setFileScannerOpts function accepts `default_recursive` option.
  - A new `jsontag` plugin for converting tags to JSON.
  - A new `extract` plugin for extracting tags from media.
  - A new `yamltag` plugin for converting tags to YAML.
  - A new `mimetypes` plugin for listing file mime-types / measuring performance
  - Original artist support (TOPE frame, --orig-artist)
  - Added support for Python 3.8 and pypy3.
  - Log warning when ID3 v1.x text truncation occurs. Fixes #299.
  - Accept (invalid) date strings for the form YYYYMMDD. Fixes #379
  - Adjust replay gain correctly for lame >= 3.95.1 headers.
  - Added -r/--recursive argument. eyeD3 is no longer recursive by default (#378)
  - Regenerated grako parser.
  - New ValueError for _setNum when unknown type/values are passed.
  - Moved src/* to top-level repo directory.
  - PRIV data type checking, fixed examples, etc.
  - Use tox for `make test`
  - ID3 v2.3 to v2.4 date conversion.
  - Match mp3 mime-types against all possible mime-types.
    Specifically, application/x-font-gdos. Fixes #338
  - Fix simple typo: titel -> title. <tim.gates@iress.com>
  - Fixed: load the right config file in arguments. <zhumumu@gmail.com>
  - Fix issue tracker link. Fixes #333.
  - Fixed art plugin when `pylast` is not installed.
  - Unbound variable for track num/total.  Fixes #327.
  - Fixed MP3 header search to not false match on BOMs.
  - Honor APIC text encoding when description is "".  #200.
  - Fixed bug with improper types when re-rendering unique file ID. (#324)
    <gabrieldiegoteixeira@gmail.com>
  - UFID fixes, update (#325) <gabrieldiegoteixeira@gmail.com>
* Sat Jul 27 2019 Stanislav Brabec <sbrabec@suse.com>
- Update to version 0.8.10:
  * See HISTORY.rst for list of changes.
- Switch to python3.
- Update license.
- Improve spec file.
* Mon Dec 28 2015 adrian@suse.de
- initial package of version 0.7.9
